'''
randopass: strong random English-word passphrases
'''

from randopass.randopass import getPass, getVersion

__version__ = getVersion()
